# 🎨 Excaligen API Documentation


This is the API documentation for the Excaligen library


✨ The following classes are available:

## SceneBuilder

* [SceneBuilder](scenebuilder.md)
    The SceneBuilder class provides methods to add various diagram elements

## Defaults

* [Defaults](defaults.md)
    A class to hold default values for various element properties

## Color

* [Color](color.md)
    Color class for handling RGB and HSL colors

## Arrow

* [Arrow](arrow.md)
    A class representing an arrow element in Excalidraw with various connection styles

## Diamond

* [Diamond](diamond.md)
    A class representing a diamond shape in the diagram

## Ellipse

* [Ellipse](ellipse.md)
    A class representing an elliptical shape element

## Frame

* [Frame](frame.md)
    A visual container that can hold other elements and automatically adjusts its size

## Group

* [Group](group.md)
    A container class that represents a group of elements

## Image

* [Image](image.md)
    A class representing an image element that can be loaded from various sources

## Line

* [Line](line.md)
    A line element that draws a straight or curved line segments between the given points

## Rectangle

* [Rectangle](rectangle.md)
    A class representing a rectangular shape in a 2D space

## Text

* [Text](text.md)
    A class representing text elements in excaligen

